==> haskell-juicypixels-3.3.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-juicypixels.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: JuicyPixels
version: 3.3.1
id: JuicyPixels-3.3.1-GoHpnhcfmT4HnjNPbV3sCn
key: JuicyPixels-3.3.1-GoHpnhcfmT4HnjNPbV3sCn
license: BSD-3-Clause
maintainer: vincent.berthoux@gmail.com
author: Vincent Berthoux
stability: Stable
homepage: https://github.com/Twinside/Juicy.Pixels
synopsis: Picture loading/serialization (in png, jpeg, bitmap, gif, tga, tiff and radiance)
description:
    <<data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMAAAADABAMAAACg8nE0AAAAElBMVEUAAABJqDSTWEL/qyb///8AAABH/1GTAAAAAXRSTlMAQObYZgAAAN5JREFUeF7s1sEJgFAQxFBbsAV72v5bEVYWPwT/XDxmCsi7zvHXavYREBDI3XP2GgICqBBYuwIC+/rVayPUAyAg0HvIXBcQoDFDGnUBgWQQ2Bx3AYFaRoBpAQHWb3bt2ARgGAiCYFFuwf3X5HA/McgGJWI2FdykCv4aBYzmKwDwvl6NVmUAAK2vlwEALK7fo88GANB6HQsAAAAAAAAA7P94AQCzswEAAAAAAAAAAAAAAAAAAICzh4UAO4zWAYBfRutHA4Bn5C69JhowAMGoBaMWDG0wCkbBKBgFo2AUAACPmegUST/IJAAAAABJRU5ErkJggg==>>
    .
    This library can load and store images in PNG,Bitmap, Jpeg, Radiance, Tiff and Gif images.
category: Codec, Graphics, Image
abi: 4eee1b67d5e5ca2195c7df887bb0e917
exposed: True
exposed-modules:
    Codec.Picture Codec.Picture.Bitmap Codec.Picture.ColorQuant
    Codec.Picture.Gif Codec.Picture.HDR Codec.Picture.Jpg
    Codec.Picture.Metadata Codec.Picture.Metadata.Exif
    Codec.Picture.Png Codec.Picture.Saving Codec.Picture.Tga
    Codec.Picture.Tiff Codec.Picture.Types
hidden-modules: Codec.Picture.Jpg.DefaultTable
                Codec.Picture.Jpg.Metadata Codec.Picture.Jpg.FastIdct
                Codec.Picture.Jpg.FastDct Codec.Picture.Jpg.Types
                Codec.Picture.Jpg.Common Codec.Picture.Jpg.Progressive
                Codec.Picture.Gif.LZW Codec.Picture.Gif.LZWEncoding
                Codec.Picture.Png.Export Codec.Picture.Png.Type
                Codec.Picture.Png.Metadata Codec.Picture.Tiff.Metadata
                Codec.Picture.Tiff.Types Codec.Picture.BitWriter
                Codec.Picture.InternalHelper Codec.Picture.VectorByteConversion
import-dirs: /usr/lib/ghc-8.4.3/site-local/JuicyPixels-3.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/JuicyPixels-3.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/JuicyPixels-3.3.1
hs-libraries: HSJuicyPixels-3.3.1-GoHpnhcfmT4HnjNPbV3sCn
include-dirs: /usr/lib/ghc-8.4.3/site-local/JuicyPixels-3.3.1/include
depends:
    base-4.11.1.0 bytestring-0.10.8.2 mtl-2.2.2 binary-0.8.5.1
    zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH transformers-0.5.5.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc deepseq-1.4.3.0
    containers-0.5.11.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             binary-0.8.5.1=758db3c95031800de821949083b71c7f
             zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH=ef1ac153a45a86b7156d838914c2c4aa
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=a76404d2410541ab4c0cf63ee4e3a316
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
haddock-interfaces: /usr/share/doc/haskell-juicypixels/html/JuicyPixels.haddock
haddock-html: /usr/share/doc/haskell-juicypixels/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-juicypixels-3.3.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-juicypixels.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: JuicyPixels
version: 3.3.2
id: JuicyPixels-3.3.2-7JfEF0h4GbzKiW4vd5wqJT
key: JuicyPixels-3.3.2-7JfEF0h4GbzKiW4vd5wqJT
license: BSD-3-Clause
maintainer: vincent.berthoux@gmail.com
author: Vincent Berthoux
stability: Stable
homepage: https://github.com/Twinside/Juicy.Pixels
synopsis: Picture loading/serialization (in png, jpeg, bitmap, gif, tga, tiff and radiance)
description:
    <<data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMAAAADABAMAAACg8nE0AAAAElBMVEUAAABJqDSTWEL/qyb///8AAABH/1GTAAAAAXRSTlMAQObYZgAAAN5JREFUeF7s1sEJgFAQxFBbsAV72v5bEVYWPwT/XDxmCsi7zvHXavYREBDI3XP2GgICqBBYuwIC+/rVayPUAyAg0HvIXBcQoDFDGnUBgWQQ2Bx3AYFaRoBpAQHWb3bt2ARgGAiCYFFuwf3X5HA/McgGJWI2FdykCv4aBYzmKwDwvl6NVmUAAK2vlwEALK7fo88GANB6HQsAAAAAAAAA7P94AQCzswEAAAAAAAAAAAAAAAAAAICzh4UAO4zWAYBfRutHA4Bn5C69JhowAMGoBaMWDG0wCkbBKBgFo2AUAACPmegUST/IJAAAAABJRU5ErkJggg==>>
    .
    This library can load and store images in PNG,Bitmap, Jpeg, Radiance, Tiff and Gif images.
category: Codec, Graphics, Image
abi: f13b832e773391c9f24e8188ba882819
exposed: True
exposed-modules:
    Codec.Picture Codec.Picture.Bitmap Codec.Picture.ColorQuant
    Codec.Picture.Gif Codec.Picture.HDR Codec.Picture.Jpg
    Codec.Picture.Metadata Codec.Picture.Metadata.Exif
    Codec.Picture.Png Codec.Picture.Saving Codec.Picture.Tga
    Codec.Picture.Tiff Codec.Picture.Types
hidden-modules: Codec.Picture.Jpg.DefaultTable
                Codec.Picture.Jpg.Metadata Codec.Picture.Jpg.FastIdct
                Codec.Picture.Jpg.FastDct Codec.Picture.Jpg.Types
                Codec.Picture.Jpg.Common Codec.Picture.Jpg.Progressive
                Codec.Picture.Gif.LZW Codec.Picture.Gif.LZWEncoding
                Codec.Picture.Png.Export Codec.Picture.Png.Type
                Codec.Picture.Png.Metadata Codec.Picture.Tiff.Metadata
                Codec.Picture.Tiff.Types Codec.Picture.BitWriter
                Codec.Picture.InternalHelper Codec.Picture.VectorByteConversion
import-dirs: /usr/lib/ghc-8.4.3/site-local/JuicyPixels-3.3.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/JuicyPixels-3.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/JuicyPixels-3.3.2
hs-libraries: HSJuicyPixels-3.3.2-7JfEF0h4GbzKiW4vd5wqJT
include-dirs: /usr/lib/ghc-8.4.3/site-local/JuicyPixels-3.3.2/include
depends:
    base-4.11.1.0 bytestring-0.10.8.2 mtl-2.2.2 binary-0.8.5.1
    zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH transformers-0.5.5.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc deepseq-1.4.3.0
    containers-0.5.11.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             binary-0.8.5.1=758db3c95031800de821949083b71c7f
             zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH=ef1ac153a45a86b7156d838914c2c4aa
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=a76404d2410541ab4c0cf63ee4e3a316
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
haddock-interfaces: /usr/share/doc/haskell-juicypixels/html/JuicyPixels.haddock
haddock-html: /usr/share/doc/haskell-juicypixels/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
